==> knative-model-6.8.0-sources.jar: io/fabric8/knative/internal/networking/v1alpha1/ClusterDomainClaimSpecFluent.java <==
package io.fabric8.knative.internal.networking.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterDomainClaimSpecFluent<A extends ClusterDomainClaimSpecFluent<A>> extends BaseFluent<A>{
  public ClusterDomainClaimSpecFluent() {
  }
  public ClusterDomainClaimSpecFluent(ClusterDomainClaimSpec instance) {
    instance = (instance != null ? instance : new ClusterDomainClaimSpec());

    if (instance != null) {
      this.withNamespace(instance.getNamespace());
      this.withNamespace(instance.getNamespace());
    }
  }
  private String namespace;
  public String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public boolean hasNamespace() {
    return this.namespace != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterDomainClaimSpecFluent that = (ClusterDomainClaimSpecFluent) o;
    if (!java.util.Objects.equals(namespace, that.namespace)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(namespace,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (namespace != null) { sb.append("namespace:"); sb.append(namespace); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> knative-model-6.9.0-sources.jar: io/fabric8/knative/internal/networking/v1alpha1/ClusterDomainClaimSpecFluent.java <==
package io.fabric8.knative.internal.networking.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ClusterDomainClaimSpecFluent<A extends ClusterDomainClaimSpecFluent<A>> extends BaseFluent<A>{
  public ClusterDomainClaimSpecFluent() {
  }
  
  public ClusterDomainClaimSpecFluent(ClusterDomainClaimSpec instance) {
    this.copyInstance(instance);
  }
  private String namespace;
  
  protected void copyInstance(ClusterDomainClaimSpec instance) {
    instance = (instance != null ? instance : new ClusterDomainClaimSpec());
  
    if (instance != null) {
        this.withNamespace(instance.getNamespace());
        this.withNamespace(instance.getNamespace());
      }
  }
  
  public String getNamespace() {
    return this.namespace;
  }
  
  public A withNamespace(String namespace) {
    this.namespace=namespace; return (A) this;
  }
  
  public boolean hasNamespace() {
    return this.namespace != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterDomainClaimSpecFluent that = (ClusterDomainClaimSpecFluent) o;
    if (!java.util.Objects.equals(namespace, that.namespace)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(namespace,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (namespace != null) { sb.append("namespace:"); sb.append(namespace); }
    sb.append("}");
    return sb.toString();
  }
  

}
